# Rectified Linear Unit Function with all arguments default
activation_curve()
# Sigmoid function with domain from -5 to 5.
activation_curve(expr="sigmoid", title="Sigmoid Function", xmin=-5, xmax=5)
# Define a parametric ReLU in the argument of \code{expr}.
activation_curve(expr="(x>=0)*x+0.2*x*(x<0)", title="Parametric Rectified Linear Unit Function")
# Suppress the output of 'LaTeX' code to be directly printed on the console and save the output
# to an object, which can be printed later at demand.
nnd_activation <- activation_curve(suppress=TRUE)
cat(paste(nnd_activation,"\n"))
Run the code above in your browser using DataLab