# A neural network with 3 neurons on input layer, 6 neurons on each of 3 hidden layers,
# and 1 neuron on output layer. All other arguments are default, so no neuron is
# drawn with lighter color.
nndiagram_nodeCoverup(input=3, hidden=c(6,6,6))
# Same as the first example but neurons indexed with 4 and 11 are designed to be drawn
# with lighter color.
nndiagram_nodeCoverup(input=3, hidden=c(6,6,6), node.coverup=c(4,10))
# Same as the first example but distance between layers is defined to be smaller.
nndiagram_nodeCoverup(input=3, hidden=c(6,6,6), layer.sep=1.5)
# Suppress the output of 'LaTeX' code to be directly printed on the console and save the output
# to an object, which can be printed later at demand.
nnd_nodeCoverup <- nndiagram_nodeCoverup(input=3, hidden=c(6,6,6), suppress=TRUE)
cat(paste(nnd_nodeCoverup,"\n"))
Run the code above in your browser using DataLab