# A neural network with 3 neurons on input layer, 6 neurons on each of 3 hidden layers, and 1 neuron
# on output layer. All other arguments are default, so no layer is considered to be over-sized.
nndiagram_oversize(input=3, hidden=c(6,6,6))
# Same as the first example but cutoff value of size is designed to be 5, so all hidden layers are
# considered to be over-sized.
nndiagram_oversize(input=3, hidden=c(6,6,6), size.cutoff=5)
# Same as the second example but labels of input neurons are designed to be letters from a to c.
nndiagram_oversize(input=3, hidden=c(6,6,6), size.cutoff=5, input.label=letters[1:3])
# Suppress the output of 'LaTeX' code to be directly printed on the console and save the output
# to an object, which can be printed later at demand.
nnd_oversize <- nndiagram_oversize(input=3, hidden=c(6,6,6), size.cutoff=5, suppress=TRUE)
cat(paste(nnd_oversize,"\n"))
Run the code above in your browser using DataLab